#!/usr/bin/python2.4
# -*- coding: utf-8 -*-
#
# Statistics of QR codes in the book: "Digital art in Wallonia-Brussels Federation Grants 2006-2010
#
# This script queries the Google urlshortner API to get analytics related to the QR codes used in the book. 
# (Yes, those QR codes point to a goo.gl short url!) And outputs the results in the "output.csv" file
# This code is provided as-is. Should work as expected. Don't complain if it breaks your system. Use it wisely. ;)
# Cheers to Jérôme "G_Rom" Clerfayt for scanning all the QR codes. 
# This put together in an afternoon on the 4th of November 2011
#
# Author: Julien "Juego" Deswaef
# Contact: juego [at] requiem4tv.com
# Url: http://xuv.be - http://requiem4tv.com
# License: https://www.gnu.org/copyleft/gpl.html
#
# Requires the Google API Python Client library
# Google documentation: https://code.google.com/apis/urlshortener/v1/getting_started.html
# The url description to GET statistics
# GET https://www.googleapis.com/urlshortener/v1/url?key={key}&shortUrl={shortUrl}&projection={projection?}

import httplib2
import simplejson as json
import time

h = httplib2.Http()

api_key = "AIzaSyD4750YPtAWwF5pKs-zddwSJpRZhWMt0yE"
short_url_base = "http://goo.gl/"
goo_gl_id = "woZDQ" # Requiem4tv
filename = "qr-codes.csv"

file = open(filename, "r")
lines = file.read().split("\n")
lines.pop(0) # Remove the titles from the csv file
file.close()

# Projection can be either: 
# "FULL" - returns the creation timestamp and all available analytics
# "ANALYTICS_CLICKS" - returns only click counts
# "ANALYTICS_TOP_STRINGS" - returns only top string counts (e.g. referrers, countries, etc)
projection = "ANALYTICS_CLICKS"

output = open("output.csv", "w")
output.write("Google QR code id,Artist name,Total clicks " + time.strftime("%d/%b/%Y %H:%M") + "\n")

for l in lines:
	if l != " ":
		artist = l.split(",")
		short_url = short_url_base + artist[0]
		uri = "https://www.googleapis.com/urlshortener/v1/url?key=" + api_key + "&shortUrl=" + short_url + "&projection=" + projection

		# resp = header response, content = data
		resp, content = h.request( uri, "GET")

		result = json.loads(content)
		
		#print content
		totalClicks = result['analytics']['allTime']['shortUrlClicks']
		print artist[1] + " :\t " + totalClicks
		
		output.write( l + "," + totalClicks + "\n")
		
		# Google rule: wait 1 sec before making another API call
		time.sleep(1) 
		
output.close()
